@@ -1,22 +1,26 @@
 {-# LANGUAGE ScopedTypeVariables, FlexibleInstances, MultiParamTypeClasses, UndecidableInstances, ExistentialQuantification, Rank2Types, CPP #-}
 
 {- |
-    /RECOMMENDATION/: Use "Data.Generics.Uniplate.Data" instead.
+    /DEPRECATED/: Use "Data.Generics.Uniplate.Data" instead.
 
     This module exports 'Biplate' instances for everything with 'Data' defined.
     Using GHC the 'Data' instances can be constructed with @deriving Data@.
 -}
-module Data.Generics.PlateData(
+module Data.Generics.PlateData
+    {-# DEPRECATED "Use Data.Generics.Uniplate.Data instead" #-}
+    (
     module Data.Generics.Biplate
     ) where
 
 import Data.Generics.Biplate
 import Data.Generics.PlateInternal
 import Data.Generics
+
+#if !(__GLASGOW_HASKELL__ < 606 || __GLASGOW_HASKELL__ >= 702)
 import Data.List
 import qualified Data.IntSet as IntSet
 import Data.Ratio
-
+#endif
 
 
 -- | An existential box representing a type which supports SYB
@@ -35,7 +39,7 @@ containsMatch :: (Data start, Typeable start, Data find, Typeable find) =>
                  start -> find ->
                  Box find
 
-#if __GLASGOW_HASKELL__ < 606
+#if __GLASGOW_HASKELL__ < 606 || __GLASGOW_HASKELL__ >= 702
 -- GHC 6.4.2 does not export typeRepKey, so we can't do the trick
 -- as efficiently, so we just give up and revert to always following
 
